Struct clock_bound_c::Bound [−][src]
A structure for containing the error bounds returned from ClockBoundD. The values represent the time since the Unix Epoch in nanoseconds.
Fields
earliest: u64System time minus the error calculated from chrony in nanoseconds since the Unix Epoch
latest: u64System time plus the error calculated from chrony in nanoseconds since the Unix Epoch