Struct clock_bound_c::ResponseHeader [−][src]
pub struct ResponseHeader {
pub response_version: u8,
pub response_type: u8,
pub unsynchronized_flag: bool,
}Expand description
A structure for holding the header of the received response.
Fields
response_version: u8The version of the response received from ClockBoundD.
response_type: u8The type of the response received from ClockBoundD.
unsynchronized_flag: boolA flag representing if Chrony is reporting as unsynchronized.