Struct clock_bound_c::ResponseNow[][src]

pub struct ResponseNow {
    pub header: ResponseHeader,
    pub bound: Bound,
    pub timestamp: u64,
}
A structure for holding the response of a now request.

Fields

header: ResponseHeaderbound: Boundtimestamp: u64

The timestamp, represented as nanoseconds since the Unix Epoch, bounded against.