Struct clock_bound_c::ResponseBefore [−][src]
pub struct ResponseBefore {
pub header: ResponseHeader,
pub before: bool,
}Expand description
A structure for holding the response of a before request.
Fields
header: ResponseHeaderbefore: boolA boolean indicating if the requested time is before the current error bounds or not.